# langchain-ibm

This package contains the LangChain integrations for IBM watsonx.ai through their `ibm-watsonx-ai` SDK.

## Installation and Setup

- Install the LangChain partner package
```bash
pip install langchain-ibm
```

## LLM

See a [usage example](https://python.langchain.com/docs/integrations/llms/watsonxllm).

```python
from langchain_ibm import WatsonxLLM
```
